@@ -100,7 +100,7 @@ enum
 struct _GdaParameterPrivate
 {
 	GSList                *param_users; /* list of #GdaObject using that parameter */
-	GType                  gda_type;
+	GType                  g_type;
 	GdaParameter          *alias_of;     /* FULL bind to param */
 	GdaParameter          *change_with;  /* SIMPLE bind to param */
 	
@@ -198,7 +198,7 @@ gda_parameter_class_init (GdaParameterClass *class)
 	object_class->set_property = gda_parameter_set_property;
 	object_class->get_property = gda_parameter_get_property;
         g_object_class_install_property (object_class, PROP_GDA_TYPE,
-                                         g_param_spec_ulong ("gda_type", NULL, NULL,
+                                         g_param_spec_ulong ("g_type", NULL, NULL,
 							   0, G_MAXULONG, GDA_TYPE_NULL,
 							   (G_PARAM_READABLE | 
 							    G_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY)));
@@ -231,7 +231,7 @@ gda_parameter_init (GdaParameter *parameter)
 {
 	parameter->priv = g_new0 (GdaParameterPrivate, 1);
 	parameter->priv->param_users = NULL;
-	parameter->priv->gda_type = G_TYPE_INVALID;
+	parameter->priv->g_type = G_TYPE_INVALID;
 	parameter->priv->alias_of = NULL;
 	parameter->priv->change_with = NULL;
 
@@ -263,7 +263,7 @@ gda_parameter_new (GType type)
 
 	g_return_val_if_fail (type != G_TYPE_INVALID, NULL);
 
-        obj = g_object_new (GDA_TYPE_PARAMETER, "gda_type", type, NULL);
+        obj = g_object_new (GDA_TYPE_PARAMETER, "g_type", type, NULL);
 
         return (GdaParameter *) obj;
 }
@@ -288,7 +288,7 @@ gda_parameter_new_copy (GdaParameter *orig)
 	g_return_val_if_fail (orig->priv, NULL);
 
 	dict = gda_object_get_dict (GDA_OBJECT (orig));
-	obj = g_object_new (GDA_TYPE_PARAMETER, "dict", dict,"gda_type", orig->priv->gda_type, NULL);
+	obj = g_object_new (GDA_TYPE_PARAMETER, "dict", dict,"g_type", orig->priv->g_type, NULL);
 	param = GDA_PARAMETER (obj);
 
 	gda_object_set_name (GDA_OBJECT (param), gda_object_get_name (GDA_OBJECT (orig)));
@@ -416,7 +416,7 @@ gda_parameter_dispose (GObject *object)
 		while (parameter->priv->param_users)
 			gda_parameter_del_user (parameter, GDA_OBJECT (parameter->priv->param_users->data));
 
-		parameter->priv->gda_type = G_TYPE_INVALID;
+		parameter->priv->g_type = G_TYPE_INVALID;
 
 		if (parameter->priv->value) {
 			gda_value_free (parameter->priv->value);
@@ -468,7 +468,7 @@ gda_parameter_set_property    (GObject *object,
 	if (parameter->priv) {
 		switch (param_id) {
 		case PROP_GDA_TYPE:
-			parameter->priv->gda_type = g_value_get_ulong (value);
+			parameter->priv->g_type = g_value_get_ulong (value);
 			break;
 		case PROP_PLUGIN:
 			ptr = g_value_get_string (value);
@@ -523,7 +523,7 @@ gda_parameter_get_property    (GObject *object,
 	if (parameter->priv) {
 		switch (param_id) {
 		case PROP_GDA_TYPE:
-			g_value_set_ulong (value, parameter->priv->gda_type);
+			g_value_set_ulong (value, parameter->priv->g_type);
 		case PROP_PLUGIN:
 			g_value_set_string (value, parameter->priv->plugin);
 			break;
@@ -610,7 +610,7 @@ gda_parameter_replace_param_users (GdaParameter *param, GHashTable *replacements
 }
 
 /**
- * gda_parameter_get_gda_type
+ * gda_parameter_get_g_type
  * @param: a #GdaParameter object
  * 
  * Get the requested data type for @param.
@@ -618,12 +618,12 @@ gda_parameter_replace_param_users (GdaParameter *param, GHashTable *replacements
  * Returns: the data type
  */
 GType
-gda_parameter_get_gda_type (GdaParameter *param)
+gda_parameter_get_g_type (GdaParameter *param)
 {
 	g_return_val_if_fail (GDA_IS_PARAMETER (param), G_TYPE_INVALID);
 	g_return_val_if_fail (param->priv, G_TYPE_INVALID);
 
-	return param->priv->gda_type;
+	return param->priv->g_type;
 }
 
 
@@ -670,7 +670,10 @@ gda_parameter_set_value (GdaParameter *param, const GValue *value)
 {
 	gboolean changed = TRUE;
 	const GValue *current_val;
-#ifdef GDA_DEBUG_NO
+#define DEBUG_PARAM
+#undef DEBUG_PARAM
+
+#ifdef DEBUG_PARAM
 	gboolean was_valid = gda_parameter_is_valid (param);
 #endif
 
@@ -700,10 +703,10 @@ gda_parameter_set_value (GdaParameter *param, const GValue *value)
 
 	if (value &&
 	    (G_VALUE_TYPE ((GValue *)value) != GDA_TYPE_NULL) &&
-	    (G_VALUE_TYPE ((GValue *)value) != param->priv->gda_type))
+	    (G_VALUE_TYPE ((GValue *)value) != param->priv->g_type))
 		param->priv->valid = FALSE;
 
-#ifdef GDA_DEBUG_NO
+#ifdef DEBUG_PARAM
 	g_print ("Changed param %p (%s): value %s --> %s \t(type %d -> %d) VALID: %d->%d CHANGED: %d\n", 
 		 param, gda_object_get_name (param),
 		 current_val ? gda_value_stringify ((GValue *)current_val) : "_NULL_",
@@ -720,7 +723,7 @@ gda_parameter_set_value (GdaParameter *param, const GValue *value)
 			g_object_get (G_OBJECT (param), "changed_blocked", &changed_blocked, NULL);
 			if (!changed_blocked) {
 				g_object_set_data (G_OBJECT (param), "changed_pending", NULL);
-				gda_object_changed (GDA_OBJECT (param));
+				gda_object_signal_emit_changed (GDA_OBJECT (param));
 			}
 		}
 		return;
@@ -731,7 +734,7 @@ gda_parameter_set_value (GdaParameter *param, const GValue *value)
 
 	/* real setting of the value */
 	if (param->priv->alias_of) {
-#ifdef GDA_DEBUG_NO
+#ifdef DEBUG_PARAM
 		g_print ("Param %p is alias of param %p => propagating changes to param %p\n",
 			 param, param->priv->alias_of, param->priv->alias_of);
 #endif
@@ -754,7 +757,7 @@ gda_parameter_set_value (GdaParameter *param, const GValue *value)
 		if (changed_blocked)
 			g_object_set_data (G_OBJECT (param), "changed_pending", GINT_TO_POINTER (TRUE));
 		else
-			gda_object_changed (GDA_OBJECT (param));
+			gda_object_signal_emit_changed (GDA_OBJECT (param));
 	}
 }
 
@@ -785,9 +788,9 @@ gda_parameter_set_value_str (GdaParameter *param, const gchar *value)
 		GdaDataHandler *dh;
 
 		dict = gda_object_get_dict (GDA_OBJECT (param));
-		dh = gda_dict_get_handler (dict, param->priv->gda_type);
+		dh = gda_dict_get_handler (dict, param->priv->g_type);
 		if (dh)
-			gdaval = gda_data_handler_get_value_from_str (dh, value, param->priv->gda_type);
+			gdaval = gda_data_handler_get_value_from_str (dh, value, param->priv->g_type);
 		
 		if (gdaval) {
 			gda_parameter_set_value (param, gdaval);
@@ -831,7 +834,7 @@ gda_parameter_declare_invalid (GdaParameter *param)
 	if (param->priv->alias_of) 
 		gda_parameter_declare_invalid (param->priv->alias_of);
 	else 
-		gda_object_changed (GDA_OBJECT (param));
+		gda_object_signal_emit_changed (GDA_OBJECT (param));
 }
 
 
@@ -978,7 +981,7 @@ gda_parameter_set_not_null (GdaParameter *param, gboolean not_null)
 		    (!param->priv->value || gda_value_is_null (param->priv->value)))
 			param->priv->valid = FALSE;
 
-		gda_object_changed (GDA_OBJECT (param));
+		gda_object_signal_emit_changed (GDA_OBJECT (param));
 	}
 }
 
@@ -1108,7 +1111,7 @@ gda_parameter_bind_to_param (GdaParameter *param, GdaParameter *bind_to)
 	if (bind_to) {
 		g_return_if_fail (bind_to && GDA_IS_PARAMETER (bind_to));
 		g_return_if_fail (bind_to->priv);
-		g_return_if_fail (param->priv->gda_type == bind_to->priv->gda_type);
+		g_return_if_fail (param->priv->g_type == bind_to->priv->g_type);
 		cvalue = gda_parameter_get_value (bind_to);
 		if (cvalue && !gda_value_is_null ((GValue*)cvalue))
 			value2 = gda_value_copy ((GValue*)cvalue);
@@ -1178,7 +1181,7 @@ gda_parameter_set_full_bind_param (GdaParameter *param, GdaParameter *alias_of)
 	if (alias_of) {
 		g_return_if_fail (alias_of && GDA_IS_PARAMETER (alias_of));
 		g_return_if_fail (alias_of->priv);
-		g_return_if_fail (param->priv->gda_type == alias_of->priv->gda_type);
+		g_return_if_fail (param->priv->g_type == alias_of->priv->g_type);
 		cvalue = gda_parameter_get_value (alias_of);
 		if (cvalue && !gda_value_is_null ((GValue*)cvalue))
 			value2 = gda_value_copy ((GValue*)cvalue);
@@ -1224,7 +1227,7 @@ gda_parameter_set_full_bind_param (GdaParameter *param, GdaParameter *alias_of)
 		}
 
 		if (!equal)
-			gda_object_changed (GDA_OBJECT (param));
+			gda_object_signal_emit_changed (GDA_OBJECT (param));
 	}
 	else {
 		/* restore the value that was in the previous alias parameter, 
@@ -1253,7 +1256,7 @@ alias_of_changed_cb (GdaParameter *alias_of, GdaParameter *param)
 {
 	if ((gpointer) alias_of == (gpointer) param->priv->alias_of) {
 		/* callback used as full bind */
-		gda_object_changed (GDA_OBJECT (param));
+		gda_object_signal_emit_changed (GDA_OBJECT (param));
 	}
 	else {
 		/* callback used as simple bind */
@@ -1312,7 +1315,7 @@ gda_parameter_dump (GdaParameter *parameter, guint offset)
 		strval = gda_value_stringify ((GValue *) gda_parameter_get_value (parameter));
 		g_print ("%s" D_COL_H1 "GdaParameter %p (%s), type=%s, %s, value=%s\n" D_COL_NOR, str, parameter,
 			 gda_object_get_name (GDA_OBJECT (parameter)), 
-			 gda_type_to_string (parameter->priv->gda_type),
+			 g_type_to_string (parameter->priv->g_type),
 			 gda_parameter_is_valid (parameter) ? "VALID" : "INVALID",
 			 strval);
 		g_free (strval);
@@ -1341,8 +1344,9 @@ gda_parameter_dump (GdaParameter *parameter, guint offset)
 			g_print ("\n");
 
 		if (parameter->priv->restrict_model) {
-				g_print ("%sValues restrictions: COLUMN %d\n", str, 
-					 parameter->priv->restrict_col);
+				g_print ("%sParameter restricted by column %d of data model %p\n", str,
+					 parameter->priv->restrict_col,
+					 parameter->priv->restrict_model);
 				gda_object_dump (GDA_OBJECT (parameter->priv->restrict_model), offset+5);
 		}
 
