@@ -26,7 +26,7 @@
 #include "gda-firebird-provider.h"
 #include "gda-firebird-blob.h"
 #include <libgda/gda-quark-list.h>
-#include <libgda/gda-intl.h>
+#include <glib/gi18n-lib.h>
 #include <glib/gprintf.h>
 #include <string.h>
 #include <math.h>
@@ -35,7 +35,7 @@
 #undef PARENT_TYPE
 #endif
                                                                                                                             
-#define PARENT_TYPE GDA_TYPE_DATA_MODEL_BASE
+#define PARENT_TYPE GDA_TYPE_DATA_MODEL_ROW
 
 struct _GdaFirebirdRecordsetPrivate {
 	GdaConnection *cnc;
@@ -57,18 +57,18 @@ static void 			gda_firebird_recordset_init (GdaFirebirdRecordset *recset,
 							     GdaFirebirdRecordsetClass *klass);
 static void 			gda_firebird_recordset_finalize (GObject *object);
 
-static gint			gda_firebird_recordset_get_n_rows (GdaDataModelBase *model);
-static gint			gda_firebird_recordset_get_n_columns (GdaDataModelBase *model);
+static gint			gda_firebird_recordset_get_n_rows (GdaDataModelRow *model);
+static gint			gda_firebird_recordset_get_n_columns (GdaDataModelRow *model);
 static void       	        gda_firebird_recordset_describe_column (GdaDataModel *model, gint col);
-static const GdaRow 	       *gda_firebird_recordset_get_row (GdaDataModelBase *model,
-								gint row);
-static const GdaValue 	       *gda_firebird_recordset_get_value_at (GdaDataModelBase *model,
+static const GdaRow 	       *gda_firebird_recordset_get_row (GdaDataModelRow *model,
+								gint row, GError **error);
+static const GValue 	       *gda_firebird_recordset_get_value_at (GdaDataModelRow *model,
 								     gint col,
 								     gint row);
-static gboolean			gda_firebird_recordset_is_updatable (GdaDataModelBase *model);
-static const GdaRow 	       *gda_firebird_recordset_append_values (GdaDataModelBase *model,
+static gboolean			gda_firebird_recordset_is_updatable (GdaDataModelRow *model);
+static const GdaRow 	       *gda_firebird_recordset_append_values (GdaDataModelRow *model,
 								      const GList *values);
-static gboolean			gda_firebird_recordset_remove_row (GdaDataModelBase *model,
+static gboolean			gda_firebird_recordset_remove_row (GdaDataModelRow *model,
 								   const GdaRow *row);
 
 static GObjectClass *parent_class = NULL;
@@ -77,48 +77,48 @@ static GObjectClass *parent_class = NULL;
 /* Firebird utility functions  */
 /*******************************/
 
-static GdaValueType
-fb_sql_type_to_gda_type (const gshort field_type, gboolean has_decimals)
+static GType
+fb_sql_type_to_g_type (const gshort field_type, gboolean has_decimals)
 {
 	switch (field_type && ~1) {
 		case SQL_BLOB:
 		case SQL_BLOB+1:
-			return GDA_VALUE_TYPE_BLOB;
+			return GDA_TYPE_BLOB;
 		case SQL_TIMESTAMP:
 		case SQL_TIMESTAMP+1:
-			return GDA_VALUE_TYPE_TIMESTAMP;
+			return GDA_TYPE_TIMESTAMP;
 		case SQL_TYPE_TIME:
 		case SQL_TYPE_TIME+1:
-			return GDA_VALUE_TYPE_TIME;
+			return GDA_TYPE_TIME;
 		case SQL_TYPE_DATE:
 		case SQL_TYPE_DATE+1:
-			return GDA_VALUE_TYPE_DATE;
+			return G_TYPE_DATE;
 		case SQL_TEXT:
 		case SQL_TEXT+1:
 		case SQL_VARYING:
 		case SQL_VARYING+1:
-			return GDA_VALUE_TYPE_STRING;
+			return G_TYPE_STRING;
 		case SQL_SHORT:
 		case SQL_SHORT+1:
-			return GDA_VALUE_TYPE_SMALLINT;
+			return GDA_TYPE_SHORT;
 		case SQL_LONG:
 		case SQL_LONG+1:
 			if (has_decimals)
-				return GDA_VALUE_TYPE_NUMERIC;
+				return GDA_TYPE_NUMERIC;
 			else
-				return GDA_VALUE_TYPE_INTEGER;
+				return G_TYPE_INT;
 				
 		case SQL_INT64:
 		case SQL_INT64+1:
-			return GDA_VALUE_TYPE_NUMERIC;
+			return GDA_TYPE_NUMERIC;
 		case SQL_FLOAT:
 		case SQL_FLOAT+1:
-			return GDA_VALUE_TYPE_SINGLE;
+			return G_TYPE_FLOAT;
 		case SQL_DOUBLE:
 		case SQL_DOUBLE+1:
-			return GDA_VALUE_TYPE_DOUBLE;
+			return G_TYPE_DOUBLE;
 		default:
-			return GDA_VALUE_TYPE_UNKNOWN;
+			return G_TYPE_INVALID;
 	}
 }
 
@@ -420,14 +420,14 @@ fb_sql_execute (GdaFirebirdConnection *fcnc,
  *  @type should contain Firebirds SQL datatype of @value
  */
 static void
-fb_gda_value_fill (GdaValue *gda_value,
+fb_gda_value_fill (GValue *gda_value,
 		   GdaFirebirdRecordset *recset,
 		   const gshort field_type,
 		   gint field_number,
 		   unsigned long length)
 {
 	GdaTime a_time;
-	GdaDate a_date;
+	GDate a_date;
 	GdaTimestamp a_times;
 	GdaBlob *blob = NULL;
 	struct tm *a_date_time;
@@ -500,23 +500,23 @@ fb_gda_value_fill (GdaValue *gda_value,
 			a_date.month = a_date_time->tm_mon;
 			a_date.day = a_date_time->tm_mday;
 		
-			gda_value_set_date (gda_value, (const GdaDate *) &a_date);
+			g_value_set_boxed (gda_value, (const GDate *) &a_date);
 			g_free (a_date_time);			
 			break;
 		case SQL_TEXT:
 		case SQL_TEXT+1:
-			gda_value_set_string (gda_value, (const gchar *) field_data);
+			g_value_set_string (gda_value, (const gchar *) field_data);
 			break;
 		case SQL_VARYING:
 		case SQL_VARYING+1:
 			var_text = (struct vary *) field_data;
 			var_text->vary_string[var_text->vary_length] = '\0';
 
-			gda_value_set_string (gda_value, (const gchar *) var_text->vary_string);
+			g_value_set_string (gda_value, (const gchar *) var_text->vary_string);
 			break;
 		case SQL_SHORT:
 		case SQL_SHORT+1:
-			gda_value_set_smallint (gda_value, *((gshort *) field_data));
+			gda_value_set_short (gda_value, *((gshort *) field_data));
 			break;
 		case SQL_LONG:
 		case SQL_LONG+1:
@@ -527,12 +527,12 @@ fb_gda_value_fill (GdaValue *gda_value,
 						   pow (10, (sql_result->sqlvar[field_number].sqlscale * -1)));
 
 				g_sprintf (tmp_big, "%f", i64_n);
-				gda_value_set_from_string (gda_value, tmp_big, GDA_VALUE_TYPE_NUMERIC);
+				gda_value_set_from_string (gda_value, tmp_big, GDA_TYPE_NUMERIC);
 				g_free (tmp_big);
 				break;
 			}
 			else {	/* Normal long type number */
-				gda_value_set_integer (gda_value, *((gint *) field_data));
+				g_value_set_int (gda_value, *((gint *) field_data));
 				break;
 			}
 			
@@ -548,16 +548,16 @@ fb_gda_value_fill (GdaValue *gda_value,
 			else
 				tmp_big = g_memdup (field_data, sizeof (gdouble));
 
-			gda_value_set_from_string (gda_value, (const gchar *) tmp_big, GDA_VALUE_TYPE_NUMERIC);
+			gda_value_set_from_string (gda_value, (const gchar *) tmp_big, GDA_TYPE_NUMERIC);
 			g_free (tmp_big);
 			break;
 		case SQL_FLOAT:
 		case SQL_FLOAT+1:
-			gda_value_set_single (gda_value, *((gfloat *) field_data));
+			g_value_set_float (gda_value, *((gfloat *) field_data));
 			break;
 		case SQL_DOUBLE:
 		case SQL_DOUBLE+1:
-			gda_value_set_double (gda_value, *((gdouble *) field_data));
+			g_value_set_double (gda_value, *((gdouble *) field_data));
 			break;
 		default:
 			g_print (_("Unknown Firebird's field value!\n"));
@@ -599,14 +599,14 @@ fb_sql_fetch_row (GdaFirebirdConnection *fcnc,
 			/* Create a row for the fetched data */
 			row = gda_row_new (GDA_DATA_MODEL (recset), recset->priv->ncolumns);
 
-			/* Fill each GdaValue in @row with fetched values */
+			/* Fill each GValue in @row with fetched values */
 			for (col_n = 0; col_n < recset->priv->ncolumns; col_n++) {
 
 				/* Get current field type from statement XSQLDA's variable */
 				field_type = (((gshort) recset->priv->sql_result->sqlvar[col_n].sqltype) & ~1);
 
 				/* Set row's field value */
-				fb_gda_value_fill ((GdaValue *) gda_row_get_value (row, col_n),	recset,
+				fb_gda_value_fill ((GValue *) gda_row_get_value (row, col_n),	recset,
 						   (const gint) field_type, col_n, 0);
 			}
 
@@ -628,7 +628,7 @@ fb_sql_fetch_row (GdaFirebirdConnection *fcnc,
 /**********************************************/
 
 static gint
-gda_firebird_recordset_get_n_rows (GdaDataModelBase *model)
+gda_firebird_recordset_get_n_rows (GdaDataModelRow *model)
 {
 	GdaFirebirdRecordset *recset = (GdaFirebirdRecordset *) model;
 	
@@ -638,7 +638,7 @@ gda_firebird_recordset_get_n_rows (GdaDataModelBase *model)
 }
                                                                                                                             
 static gint
-gda_firebird_recordset_get_n_columns (GdaDataModelBase *model)
+gda_firebird_recordset_get_n_columns (GdaDataModelRow *model)
 {
 	GdaFirebirdRecordset *recset = (GdaFirebirdRecordset *) model;
 	
@@ -648,8 +648,7 @@ gda_firebird_recordset_get_n_columns (GdaDataModelBase *model)
 }
 
 static const GdaRow *
-gda_firebird_recordset_get_row (GdaDataModelBase *model, 
-				gint row)
+gda_firebird_recordset_get_row (GdaDataModelRow *model, gint row, GError **error)
 {
 	GdaRow *fields = NULL;
 	GdaFirebirdConnection *fcnc;
@@ -691,8 +690,8 @@ gda_firebird_recordset_get_row (GdaDataModelBase *model,
 	return (const GdaRow *) fields;		
 }
 
-static const GdaValue *
-gda_firebird_recordset_get_value_at (GdaDataModelBase *model, 
+static const GValue *
+gda_firebird_recordset_get_value_at (GdaDataModelRow *model, 
 				     gint col,
 				     gint row)
 {
@@ -706,26 +705,26 @@ gda_firebird_recordset_get_value_at (GdaDataModelBase *model,
 	if (col >= n_cols)
 		return NULL;
 
-	fields = gda_firebird_recordset_get_row (model, row);
+	fields = gda_firebird_recordset_get_row (model, row, NULL);
 	
 	return fields != NULL ? gda_row_get_value ((GdaRow *) fields, col) : NULL;
 }
 
 static gboolean
-gda_firebird_recordset_is_updatable (GdaDataModelBase *model)
+gda_firebird_recordset_is_updatable (GdaDataModelRow *model)
 {
 	return FALSE;
 }
                                                                                                                             
 static const GdaRow *
-gda_firebird_recordset_append_values (GdaDataModelBase *model,
+gda_firebird_recordset_append_values (GdaDataModelRow *model,
 				   const GList *values)
 {
 	return NULL;
 }
 
 static gboolean
-gda_firebird_recordset_remove_row (GdaDataModelBase *model,
+gda_firebird_recordset_remove_row (GdaDataModelRow *model,
 				   const GdaRow *row)
 {
 	return FALSE;
@@ -775,7 +774,7 @@ gda_firebird_recordset_finalize (GObject *object)
 
 		/* if it exists then free it */
 		if (row != NULL)
-			gda_row_free (row);
+			g_object_unref (row);
 
 		/* Move down all existing rows */
 		g_ptr_array_remove_index (recset->priv->rows, 0);
@@ -798,7 +797,7 @@ static void
 gda_firebird_recordset_class_init (GdaFirebirdRecordsetClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
-	GdaDataModelBaseClass *model_class = GDA_DATA_MODEL_BASE_CLASS (klass);
+	GdaDataModelRowClass *model_class = GDA_DATA_MODEL_ROW_CLASS (klass);
 
 	parent_class = g_type_class_peek_parent (klass);
 
@@ -854,7 +853,7 @@ gda_firebird_recordset_describe_column (GdaDataModel *model, gint col)
 	gda_column_set_defined_size (fa, (glong) recset->priv->sql_result->sqlvar[col].sqllen);
 	gda_column_set_table (fa, (const gchar *) recset->priv->sql_result->sqlvar[col].relname);
 	gda_column_set_scale (fa, (glong) (recset->priv->sql_result->sqlvar[col].sqlscale * -1));
-	gda_column_set_gdatype (fa, fb_sql_type_to_gda_type (
+	gda_column_set_g_type (fa, fb_sql_type_to_g_type (
 							recset->priv->sql_result->sqlvar[col].sqltype,
 							(recset->priv->sql_result->sqlvar[col].sqlscale < 0)));
 	gda_column_set_position (fa, col);
